/*
 * File         : BV_AudioCapture.C
 * Author       : Tomasz Stachowiak
 * Created      : Tue Jul 28 14:50:57 1998
 * Revision     : $Revision$
 * Updated      : $Date$
 * Copyright: Northeast Parallel Architectures Center
 *            at Syracuse University 1998
 */

#include "BV_AudioCapture.h"

#include <stdio.h>
#include <dmedia/audio.h>

int BV_AudioCapture::init()
{
  return set_rate(DEFAULT_RATE);
  
}

int BV_AudioCapture::set_rate(long rate)
{
  long buf[2];
  
  buf[0] = AL_INPUT_RATE;
  buf[1] = rate;
  
  ALsetparams(AL_DEFAULT_DEVICE, buf, 2);

  return 0;
}

int BV_AudioCapture::set_gain(long gain)
{
  long buf[4];
  
  buf[0] = AL_LEFT_INPUT_ATTEN;
  buf[2] = AL_RIGHT_INPUT_ATTEN;
  buf[1] = gain;
  buf[3] = gain;
  ALsetparams(AL_DEFAULT_DEVICE, buf, 4);

  return 0;
}

long BV_AudioCapture::get_gain()
{
  long buf[4];
  
  buf[0] = AL_LEFT_INPUT_ATTEN;
  buf[2] = AL_RIGHT_INPUT_ATTEN;
  
  ALgetparams(AL_DEFAULT_DEVICE, buf, 4);

  return (buf[1] + buf[3])/2;
}

int BV_AudioCapture::open()
{
  if ((conf = ALnewconfig()) == 0)
    {
      fprintf (stderr, "Config allocation error\n");
      return -1;
    }

  if (ALsetchannels(conf, MONO) < 0)
    {
      fprintf (stderr, "Setting channel error\n");
      return -1;
    }
  if (ALsetqueuesize(conf, QSIZE) < 0)
    {
      fprintf (stderr, "Setting queue size error\n");
      return -1;
    }
  if (ALsetwidth(conf, AL_SAMPLE_16) < 0)
    {
      fprintf (stderr, "Setting sample width error\n");
      return -1;
    }

  port = ALopenport("mic", "r", conf);
  if(port == NULL)
    return -1;

  return 0;
}

void BV_AudioCapture::close()
{
  if(port != NULL)
    ALcloseport(port);
}

int BV_AudioCapture::capture(char *buffer, int size)
{
  ALreadsamps(port, buffer, size);
  return 0;
}
